@@ -106,7 +106,7 @@ client_start_event_cb(struct bufferevent *bev, short what, void *ctx)
 		}
 		debug(LOG_ERR, "Proxy connect server [%s:%d] error: %s", c_conf->server_addr, c_conf->server_port, strerror(errno));
 		bufferevent_free(bev);
-		del_proxy_client(client);
+		del_proxy_client_by_stream_id(client->stream_id);
 	} else if (what & BEV_EVENT_CONNECTED) {
 		bufferevent_setcb(bev, recv_cb, NULL, client_start_event_cb, client);
 		bufferevent_enable(bev, EV_READ|EV_WRITE);
@@ -218,7 +218,6 @@ connect_server(struct event_base *base, const char *name, const int port)
 		bufferevent_free(bev);
 		return NULL;
 	}
-	
 	return bev;
 }
 
@@ -247,6 +246,8 @@ hb_sender_cb(evutil_socket_t fd, short event, void *arg)
 	int interval = current_time - pong_time;
 	if (pong_time && interval > c_conf->heartbeat_timeout) {
 		debug(LOG_INFO, " interval [%d] greater than heartbeat_timeout [%d]", interval, c_conf->heartbeat_timeout);
+
+		reset_session_id();
 		clear_main_control();
 		run_control();
 		return;
@@ -486,7 +487,7 @@ recv_cb(struct bufferevent *bev, void *ctx)
 	if (len <= 0) {
 			return;
 	}
-	
+
 	struct common_conf 	*c_conf = get_common_config();
 	if (c_conf->tcp_mux) {
 		static struct tcp_mux_header tmux_hdr;
@@ -611,6 +612,7 @@ connect_event_cb (struct bufferevent *bev, short what, void *ctx)
 		clear_main_control();
 		run_control();
 	} else if (what & BEV_EVENT_CONNECTED) {
+		debug(LOG_DEBUG, "xfrp server connected");
 		retry_times = 0;
 		send_window_update(bev, &main_ctl->stream, 0);
 		login();
@@ -856,6 +858,8 @@ clear_main_control()
 	set_client_status(0);
 	pong_time = 0;	
 	is_login = 0;
+	if (get_common_config()->tcp_mux)
+		init_tmux_stream(&main_ctl->stream, get_next_session_id(), INIT);
 }
 
 void 
