@@ -31,6 +31,8 @@
 
 #define	MAX_STREAM_WINDOW_SIZE	256*1024
 #define	RBUF_SIZE	32*1024
+#define	WBUF_SIZE	32*1024
+
 
 struct ring_buffer {
 	uint32_t cur;
@@ -146,8 +148,10 @@ void add_stream(struct tmux_stream *stream);
 
 void del_stream(uint32_t stream_id);
 
+void clear_stream();
+
 struct tmux_stream* get_stream_by_id(uint32_t id);
 
-void tmux_stream_close(struct bufferevent *bout, struct tmux_stream *stream);
+int tmux_stream_close(struct bufferevent *bout, struct tmux_stream *stream);
 
 #endif
